==> nextcloud-23.0.9.tgz: nextcloud/apps/circles/l10n/is.js <==
OC.L10N.register(
    "circles",
    {
    "Circles" : "Hringir",
    "Circles' files" : "Skrár í hringjum",
    "Select circles to filter by" : "Veldu hringi til að sía eftir",
    "No circles found" : "Engir hringir fundust",
    "Please select circles to filter by" : "Veldu hringi til að sía eftir",
    "No files found for the selected circles" : "Engar skrár fundust með völdum hringjum",
    "You created the circle {circle}" : "Þú bjóst til hringinn {circle}",
    "{author} created the circle {circle}" : "{author} bjó til hringinn {circle}",
    "You deleted {circle}" : "Þú eyddir {circle}",
    "{author} deleted {circle}" : "{author} eyddi {circle}",
    "You linked {group} to {circle}" : "Þú tengdir {group} við {circle}",
    "{group} has been linked to {circle} by {author}" : "{group} var tengdur við {circle} af {author}",
    "You unlinked {group} from {circle}" : "Þú aftengdir {group} frá {circle}",
    "{group} has been unlinked from {circle} by {author}" : "{group} var aftengdur frá {circle} af {author}",
    "You changed the level of the linked group {group} in {circle} to %1$s" : "Þú breyttir stigi tengda hópsins {group} í {circle} yfir í %1$s",
    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author} breytti stigi tengda hópsins {group} í {circle} yfir í %1$s",
    "You sent a request to link {circle} with {remote}" : "Þú sendir inn beiðni um að tengja {circle} við {remote}",
    "{author} sent a request to link {circle} with {remote}" : "{author} sendi inn beiðni um að tengja {circle} við {remote}",
    "{remote} requested a link with {circle}" : "{remote} bað um tengingu við {circle}",
    "The request to link {circle} with {remote} has been rejected" : "Beiðni um að tengja {circle} við {remote} hefur verið hafnað",
    "The request to link {remote} with {circle} has been canceled remotely" : "Beiðni um að tengja {remote} við {circle} hefur verið hafnað fjartengt",
    "The request to link {circle} with {remote} has been accepted" : "Beiðni um að tengja {circle} við {remote} hefur verið samþykkt",
    "You dismissed the request to link {remote} with {circle}" : "Þú hunsaðir beiðni um að tengja {remote} við {circle}",
    "{author} dismissed the request to link {remote} with {circle}" : "{author} hunsaði beiðni um að tengja {remote} við {circle}",
    "You canceled the request to link {circle} with {remote}" : "Þú hættir við beiðni um að tengja {circle} við {remote}",
    "{author} canceled the request to link {circle} with {remote}" : "{author} hætti við beiðni um að tengja {circle} við {remote}",
    "You accepted the request to link {remote} with {circle}" : "Þú samþykktir beiðni um að tengja {remote} við {circle}",
    "{author} accepted the request to link {remote} with {circle}" : "{author} samþykkti beiðni um að tengja {remote} við {circle}",
    "A link between {circle} and {remote} is now up and running" : "Tenging milli {circle} og {remote} er komin á og er virk",
    "The link between {circle} and {remote} has been shutdown remotely" : "Tengingunni milli {circle} og {remote} var lokað fjartengt",
    "You closed the link between {circle} and {remote}" : "Þú lokaðir tengingunni milli {circle} og {remote}",
    "{author} closed the link between {circle} and {remote}" : "{author} lokaði tengingunni milli {circle} og {remote}",
    "You joined {circle}" : "Þú gekkst í {circle}",
    "{member} joined {circle}" : "{member} gekk í {circle}",
    "You accepted the invitation to join {circle}" : "Þú samþykktir boð um að taka þátt í {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} samþykkti boð um að taka þátt í {circle}",
    "You added {member} as member to {circle}" : "Þú bættir {member} sem meðlim í {circle}",
    "You have been added as member to {circle} by {author}" : "Þér var bætt við sem meðlimi í {circle} af {author}",
    "{member} has been added as member to {circle} by {author}" : "{member} var bætt við sem meðlimi í {circle} af {author}",
    "You added {external} to {circle}" : "Þú bættir {external} í {circle}",
    "{external} has been added to {circle} by {author}" : "{external} var bætt við í {circle} af {author}",
    "You accepted {member}'s request to join {circle}" : "Þú samþykktir beiðni frá {member} um að taka þátt í {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Beiðni þín um að ganga í {circle} var samþykkt af {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "Beiðni frá {member} um að ganga í {circle} var samþykkt af {author}",
    "You left {circle}" : "Þú gekkst úr {circle}",
    "{member} left {circle}" : "{member} gekk úr {circle}",
    "You declined the invitation to join {circle}" : "Þú hafnaðir boðinu um að taka þátt í {circle}",
    "{member} declined an invitation to join {circle}" : "{member} hafnaði boði um að taka þátt í {circle}",
    "You cancelled your request to join {circle}" : "Þú hættir við beiðni þína um að taka þátt í {circle}",
    "{member} cancelled his request to join {circle}" : "{member} hætti við beiðni um að taka þátt í {circle}",
    "You removed {member} from {circle}" : "Þú fjarlægðir {member} úr {circle}",
    "You have been removed from {circle} by {author}" : "Þú varst fjarlægður úr {circle} af {author}",
    "{member} has been removed from {circle} by {author}" : "{member} var fjarlægður úr {circle} af {author}",
    "You removed {external} from {circle}" : "Þú fjarlægðir {external} úr {circle}",
    "{external} has been removed from {circle} by {author}" : "{external} var fjarlægður úr {circle} af {author}",
    "You cancelled {member}'s invitation to join {circle}" : "Þú dróst til baka beiðni frá {member} um að taka þátt í {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "Beiðni þín um að ganga í {circle} var dregin til baka af {author}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} dró til baka boð til {member} um að taka þátt í {circle}",
    "You dismissed {member}'s request to join {circle}" : "Þú hunsaðir beiðni frá {member} um að taka þátt í {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "Beiðni þín um að ganga í {circle} var hunsuð af {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "Beiðni frá {member} um að ganga í {circle} var hunsuð af {author}",
    "You invited {member} to join {circle}" : "Þú bauðst {member} að taka þátt í {circle}",
    "You have been invited to join {circle} by {author}" : "Þér hefur verið boðið að ganga í {circle} af {author}",
    "{member} has been invited to join {circle} by {author}" : "{member} hefur verið boðið að ganga í {circle} af {author}",
    "You changed {member}'s level in {circle} to %1$s" : "Þú breyttir stigi {member} í {circle} yfir í %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} breytti stigi þínu í {circle} yfir í %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} breytti stigi {member} í {circle} yfir í %1$s",
    "You sent a request to join {circle}" : "Þú sendir beiðni um að taka þátt í {circle}",
    "{member} sent a request to join {circle}" : "{member} sendi beiðni um að taka þátt í {circle}",
    "You are the new owner of {circle}" : "Þú ert nýr eigandi {circle}",
    "{member} is the new owner of {circle}" : "{member} er nýr eigandi {circle}",
    "On events happening in a <strong>Circle</strong> of which you are a member" : "Við atburði sem gerast í <strong>hring</strong> sem þú tilheyrir",
    "Any important event in a <strong>Circle</strong> you are moderating" : "Hvaða mikilvægi atburður sem er í <strong>hring</strong> sem þú hefur umsjón með",
    "On global events happening in any <strong>Circle</strong>" : "Við almenna atburði sem gerast í hvaða <strong>hring</strong> sem er",
    "Personal" : "Persónulegur",
    "System" : "Kerfið",
    "Visible" : "Sýnilegt",
    "Open" : "Opna",
    "Hidden" : "Falinn",
    "Local" : "Staðvært",
    "Root" : "Rót (root)",
    "Federated" : "Deilt milli þjóna (skýjasambandssameign)",
    "Contact" : "Tengiliður",
    "Circle" : "Hringur",
    "Member" : "Meðlimur",
    "Moderator" : "Umsjónarmaður",
    "Admin" : "Stjórnandi",
    "Owner" : "Eigandi",
    "%s shared »%s« with you." : "%s deildi »%s« með þér.",
    "%s on %s" : "%s á %s",
    "Password to access »%1$s« shared to you by %2$s" : "Lykilorði fyrir aðgang að »%1$s« var deilt með þér af %2$s",
    "Password to access »%s«" : "Lykilorð fyrir aðgang að »%s«",
    "It is protected with the following password:" : "Það er varið með eftirfarandi lykilorði:",
    "%1$s via %2$s" : "%1$s með %2$s",
    "Click the button below to open it." : "Smelltu á hnappinn hér fyrir neðan til að opna það.",
    "Open »%s«" : "Opna »%s«",
    "Password to access files shared to you by %1$s" : "Lykilorði fyrir aðgang að skránum var deilt með þér af %$s",
    "Password to access files" : "Lykilorð fyrir aðgang að skrám",
    "%s shared multiple files with you." : "%s deildi mörgum skrám með þér.",
    "Circle not found" : "Hringur fannst ekki",
    "Circle not found " : "Hringur fannst ekki ",
    "A circle with that name exists" : "Nú þegar er til hringur með þetta nafn",
    "You cannot use the Circles Application until your administrator has allowed at least one type of circles" : "Þú getur ekki notað Hringir-forritið fyrr en kerfisstjóri er búinn að leyfa a.m.k. eina gerð hringja",
    "This member does not exist" : "Þessi meðlimur er ekki til",
    "This user is already a member of the circle" : "Þessi notandi er nú þegar meðlimur í þessum hring",
    "Federated link not found" : "Skyjasambandstengill fannst ekki",
    "This feature is not available for personal circles" : "Þessi eiginleiki er ekki tiltækur fyrir persónulega hringi",
    "The circle is not federated" : "Hringurinn er ekki í skýjasambandi",
    "You cannot join this circle" : "Þú getur ekki tekið þátt í þessum hring",
    "This member is not a moderator" : "Þessi meðlimur er ekki umsjónarmaður",
    "Insufficient privileges" : "Ekki næg réttindi",
    "This member is the owner of the circle" : "Þessi meðlimur er eigandi hringsins",
    "Level cannot be changed for this type of member" : "Ekki er hægt að breyta stigi fyrir þessa gerð meðlims",
    "You are already a member of this circle" : "Þú ert nú þegar meðlimur í þessum hring",
    "You have been blocked from this circle" : "Þú hefur verið útilokaður frá þessum hring",
    "The user is already a member of this circle" : "Notandi er nú þegar meðlimur í þessum hring",
    "The user has already been invited into this circle" : "Notandanum er þegar boðið að taka þátt í þessum hring",
    "You are now a member of the Circle \"%2$s\"" : "Þú ert núna meðlimur í hringnum \"%2$s\"",
    "You have been invited by %1$s into the Circle \"%2$s\"" : "%1$s bauð þér að ganga í hringinn \"%2$s\"",
    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s sendi beiðni um að taka þátt í hringnum \"%2$s\"",
    "Accept" : "Samþykkja",
    "Refuse" : "Neita",
    "Leave the circle" : "Ganga úr þessum hring",
    "%s" : "%s",
    "Personal Circle" : "Persónulegur hringur",
    "You need a specify a type of circle" : "Þú verður að tiltaka gerð hrings",
    "This member is not the owner of the circle" : "Þessi meðlimur er ekki eigandi hringsins",
    "This member is not an admin of the circle" : "Þessi meðlimur er ekki stjórnandi hringsins",
    "Group contains too many members" : "Hópur inniheldur of marga meðlimi",
    "This group does not exist" : "Þessi hópur er ekki til",
    "This group is already linked to the circle" : "Þessi hópur er nú þegar tengdur hringnum",
    "You cannot edit level in a personal circle" : "Þú getur ekki breytt stigum í persónulegum hring",
    "Group cannot be set as owner of a circle" : "Hópur getur ekki verið eigandi á hring",
    "now" : "núna",
    "This user does not exist" : "Þessi notandi er ekki til",
    "Email format is not valid" : "Snið póstfangsins er ekki gilt",
    "This contact is not available" : "Þessi tengiliður er ekki tiltækur",
    "Could not find share" : "Gat ekki fundið sameign",
    "Bring cloud-users closer together." : "Færir notendur tölvuskýja nær hver öðrum.",
    "No files in here" : "Engar skrár hér",
    "No entries found in this folder" : "Engar færslur fundust í þessari möppu",
    "Name" : "Nafn",
    "Size" : "Stærð",
    "Modified" : "Breytt"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");

==> nextcloud-23.0.12p0.tgz: nextcloud/apps/circles/l10n/is.js <==
OC.L10N.register(
    "circles",
    {
    "Circles" : "Hringir",
    "Circles' files" : "Skrár í hringjum",
    "Select circles to filter by" : "Veldu hringi til að sía eftir",
    "No circles found" : "Engir hringir fundust",
    "Please select circles to filter by" : "Veldu hringi til að sía eftir",
    "No files found for the selected circles" : "Engar skrár fundust með völdum hringjum",
    "You created the circle {circle}" : "Þú bjóst til hringinn {circle}",
    "{author} created the circle {circle}" : "{author} bjó til hringinn {circle}",
    "You deleted {circle}" : "Þú eyddir {circle}",
    "{author} deleted {circle}" : "{author} eyddi {circle}",
    "You linked {group} to {circle}" : "Þú tengdir {group} við {circle}",
    "{group} has been linked to {circle} by {author}" : "{group} var tengdur við {circle} af {author}",
    "You unlinked {group} from {circle}" : "Þú aftengdir {group} frá {circle}",
    "{group} has been unlinked from {circle} by {author}" : "{group} var aftengdur frá {circle} af {author}",
    "You changed the level of the linked group {group} in {circle} to %1$s" : "Þú breyttir stigi tengda hópsins {group} í {circle} yfir í %1$s",
    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author} breytti stigi tengda hópsins {group} í {circle} yfir í %1$s",
    "You sent a request to link {circle} with {remote}" : "Þú sendir inn beiðni um að tengja {circle} við {remote}",
    "{author} sent a request to link {circle} with {remote}" : "{author} sendi inn beiðni um að tengja {circle} við {remote}",
    "{remote} requested a link with {circle}" : "{remote} bað um tengingu við {circle}",
    "The request to link {circle} with {remote} has been rejected" : "Beiðni um að tengja {circle} við {remote} hefur verið hafnað",
    "The request to link {remote} with {circle} has been canceled remotely" : "Beiðni um að tengja {remote} við {circle} hefur verið hafnað fjartengt",
    "The request to link {circle} with {remote} has been accepted" : "Beiðni um að tengja {circle} við {remote} hefur verið samþykkt",
    "You dismissed the request to link {remote} with {circle}" : "Þú hunsaðir beiðni um að tengja {remote} við {circle}",
    "{author} dismissed the request to link {remote} with {circle}" : "{author} hunsaði beiðni um að tengja {remote} við {circle}",
    "You canceled the request to link {circle} with {remote}" : "Þú hættir við beiðni um að tengja {circle} við {remote}",
    "{author} canceled the request to link {circle} with {remote}" : "{author} hætti við beiðni um að tengja {circle} við {remote}",
    "You accepted the request to link {remote} with {circle}" : "Þú samþykktir beiðni um að tengja {remote} við {circle}",
    "{author} accepted the request to link {remote} with {circle}" : "{author} samþykkti beiðni um að tengja {remote} við {circle}",
    "A link between {circle} and {remote} is now up and running" : "Tenging milli {circle} og {remote} er komin á og er virk",
    "The link between {circle} and {remote} has been shutdown remotely" : "Tengingunni milli {circle} og {remote} var lokað fjartengt",
    "You closed the link between {circle} and {remote}" : "Þú lokaðir tengingunni milli {circle} og {remote}",
    "{author} closed the link between {circle} and {remote}" : "{author} lokaði tengingunni milli {circle} og {remote}",
    "You joined {circle}" : "Þú gekkst í {circle}",
    "{member} joined {circle}" : "{member} gekk í {circle}",
    "You accepted the invitation to join {circle}" : "Þú samþykktir boð um að taka þátt í {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} samþykkti boð um að taka þátt í {circle}",
    "You added {member} as member to {circle}" : "Þú bættir {member} sem meðlim í {circle}",
    "You have been added as member to {circle} by {author}" : "Þér var bætt við sem meðlimi í {circle} af {author}",
    "{member} has been added as member to {circle} by {author}" : "{member} var bætt við sem meðlimi í {circle} af {author}",
    "You added {external} to {circle}" : "Þú bættir {external} í {circle}",
    "{external} has been added to {circle} by {author}" : "{external} var bætt við í {circle} af {author}",
    "You accepted {member}'s request to join {circle}" : "Þú samþykktir beiðni frá {member} um að taka þátt í {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Beiðni þín um að ganga í {circle} var samþykkt af {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "Beiðni frá {member} um að ganga í {circle} var samþykkt af {author}",
    "You left {circle}" : "Þú gekkst úr {circle}",
    "{member} left {circle}" : "{member} gekk úr {circle}",
    "You declined the invitation to join {circle}" : "Þú hafnaðir boðinu um að taka þátt í {circle}",
    "{member} declined an invitation to join {circle}" : "{member} hafnaði boði um að taka þátt í {circle}",
    "You cancelled your request to join {circle}" : "Þú hættir við beiðni þína um að taka þátt í {circle}",
    "{member} cancelled his request to join {circle}" : "{member} hætti við beiðni um að taka þátt í {circle}",
    "You removed {member} from {circle}" : "Þú fjarlægðir {member} úr {circle}",
    "You have been removed from {circle} by {author}" : "Þú varst fjarlægður úr {circle} af {author}",
    "{member} has been removed from {circle} by {author}" : "{member} var fjarlægður úr {circle} af {author}",
    "You removed {external} from {circle}" : "Þú fjarlægðir {external} úr {circle}",
    "{external} has been removed from {circle} by {author}" : "{external} var fjarlægður úr {circle} af {author}",
    "You cancelled {member}'s invitation to join {circle}" : "Þú dróst til baka beiðni frá {member} um að taka þátt í {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "Beiðni þín um að ganga í {circle} var dregin til baka af {author}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} dró til baka boð til {member} um að taka þátt í {circle}",
    "You dismissed {member}'s request to join {circle}" : "Þú hunsaðir beiðni frá {member} um að taka þátt í {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "Beiðni þín um að ganga í {circle} var hunsuð af {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "Beiðni frá {member} um að ganga í {circle} var hunsuð af {author}",
    "You invited {member} to join {circle}" : "Þú bauðst {member} að taka þátt í {circle}",
    "You have been invited to join {circle} by {author}" : "Þér hefur verið boðið að ganga í {circle} af {author}",
    "{member} has been invited to join {circle} by {author}" : "{member} hefur verið boðið að ganga í {circle} af {author}",
    "You changed {member}'s level in {circle} to %1$s" : "Þú breyttir stigi {member} í {circle} yfir í %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} breytti stigi þínu í {circle} yfir í %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} breytti stigi {member} í {circle} yfir í %1$s",
    "You sent a request to join {circle}" : "Þú sendir beiðni um að taka þátt í {circle}",
    "{member} sent a request to join {circle}" : "{member} sendi beiðni um að taka þátt í {circle}",
    "You are the new owner of {circle}" : "Þú ert nýr eigandi {circle}",
    "{member} is the new owner of {circle}" : "{member} er nýr eigandi {circle}",
    "On events happening in a <strong>Circle</strong> of which you are a member" : "Við atburði sem gerast í <strong>hring</strong> sem þú tilheyrir",
    "Any important event in a <strong>Circle</strong> you are moderating" : "Hvaða mikilvægi atburður sem er í <strong>hring</strong> sem þú hefur umsjón með",
    "On global events happening in any <strong>Circle</strong>" : "Við almenna atburði sem gerast í hvaða <strong>hring</strong> sem er",
    "Personal" : "Persónulegur",
    "System" : "Kerfið",
    "Visible" : "Sýnilegt",
    "Open" : "Opna",
    "Hidden" : "Falinn",
    "Local" : "Staðvært",
    "Root" : "Rót (root)",
    "Federated" : "Deilt milli þjóna (skýjasambandssameign)",
    "Contact" : "Tengiliður",
    "Circle" : "Hringur",
    "Member" : "Meðlimur",
    "Moderator" : "Umsjónarmaður",
    "Admin" : "Stjórnandi",
    "Owner" : "Eigandi",
    "%s shared »%s« with you." : "%s deildi »%s« með þér.",
    "%s on %s" : "%s á %s",
    "Password to access »%1$s« shared to you by %2$s" : "Lykilorði fyrir aðgang að »%1$s« var deilt með þér af %2$s",
    "Password to access »%s«" : "Lykilorð fyrir aðgang að »%s«",
    "It is protected with the following password:" : "Það er varið með eftirfarandi lykilorði:",
    "%1$s via %2$s" : "%1$s með %2$s",
    "Click the button below to open it." : "Smelltu á hnappinn hér fyrir neðan til að opna það.",
    "Open »%s«" : "Opna »%s«",
    "Password to access files shared to you by %1$s" : "Lykilorði fyrir aðgang að skránum var deilt með þér af %$s",
    "Password to access files" : "Lykilorð fyrir aðgang að skrám",
    "%s shared multiple files with you." : "%s deildi mörgum skrám með þér.",
    "Circle not found" : "Hringur fannst ekki",
    "Circle not found " : "Hringur fannst ekki ",
    "This member does not exist" : "Þessi meðlimur er ekki til",
    "Federated link not found" : "Skyjasambandstengill fannst ekki",
    "This feature is not available for personal circles" : "Þessi eiginleiki er ekki tiltækur fyrir persónulega hringi",
    "The circle is not federated" : "Hringurinn er ekki í skýjasambandi",
    "You cannot join this circle" : "Þú getur ekki tekið þátt í þessum hring",
    "This member is not a moderator" : "Þessi meðlimur er ekki umsjónarmaður",
    "Insufficient privileges" : "Ekki næg réttindi",
    "This member is the owner of the circle" : "Þessi meðlimur er eigandi hringsins",
    "Level cannot be changed for this type of member" : "Ekki er hægt að breyta stigi fyrir þessa gerð meðlims",
    "You are already a member of this circle" : "Þú ert nú þegar meðlimur í þessum hring",
    "You have been blocked from this circle" : "Þú hefur verið útilokaður frá þessum hring",
    "You are now a member of the Circle \"%2$s\"" : "Þú ert núna meðlimur í hringnum \"%2$s\"",
    "You have been invited by %1$s into the Circle \"%2$s\"" : "%1$s bauð þér að ganga í hringinn \"%2$s\"",
    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s sendi beiðni um að taka þátt í hringnum \"%2$s\"",
    "Accept" : "Samþykkja",
    "Refuse" : "Neita",
    "Leave the circle" : "Ganga úr þessum hring",
    "%s" : "%s",
    "Personal Circle" : "Persónulegur hringur",
    "You need a specify a type of circle" : "Þú verður að tiltaka gerð hrings",
    "A circle with that name exists" : "Nú þegar er til hringur með þetta nafn",
    "This member is not the owner of the circle" : "Þessi meðlimur er ekki eigandi hringsins",
    "This member is not an admin of the circle" : "Þessi meðlimur er ekki stjórnandi hringsins",
    "Group contains too many members" : "Hópur inniheldur of marga meðlimi",
    "This group does not exist" : "Þessi hópur er ekki til",
    "This group is already linked to the circle" : "Þessi hópur er nú þegar tengdur hringnum",
    "You cannot edit level in a personal circle" : "Þú getur ekki breytt stigum í persónulegum hring",
    "Group cannot be set as owner of a circle" : "Hópur getur ekki verið eigandi á hring",
    "now" : "núna",
    "Email format is not valid" : "Snið póstfangsins er ekki gilt",
    "This contact is not available" : "Þessi tengiliður er ekki tiltækur",
    "Bring cloud-users closer together." : "Færir notendur tölvuskýja nær hver öðrum.",
    "No files in here" : "Engar skrár hér",
    "No entries found in this folder" : "Engar færslur fundust í þessari möppu",
    "Name" : "Nafn",
    "Size" : "Stærð",
    "Modified" : "Breytt",
    "You cannot use the Circles Application until your administrator has allowed at least one type of circles" : "Þú getur ekki notað Hringir-forritið fyrr en kerfisstjóri er búinn að leyfa a.m.k. eina gerð hringja",
    "This user is already a member of the circle" : "Þessi notandi er nú þegar meðlimur í þessum hring",
    "The user is already a member of this circle" : "Notandi er nú þegar meðlimur í þessum hring",
    "The user has already been invited into this circle" : "Notandanum er þegar boðið að taka þátt í þessum hring",
    "This user does not exist" : "Þessi notandi er ekki til",
    "Could not find share" : "Gat ekki fundið sameign"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
